@@ -156,10 +156,10 @@ def DeleteGameConfirm():
 	TopIndex = GemRB.GetVar("TopIndex")
 	Pos = TopIndex +GemRB.GetVar("SaveIdx")
 	GemRB.DeleteSaveGame (Games[Pos])
+	del Games[Pos]
 	if TopIndex>0:
 		GemRB.SetVar("TopIndex",TopIndex-1)
-	Games = GemRB.GetSaveGames()
-	#del Games[pos]
+	#Games = GemRB.GetSaveGames()
 	ScrollBar.SetVarAssoc("TopIndex", len(Games))
 	ScrollBarPress()
 	if ConfirmWindow:
@@ -168,8 +168,11 @@ def DeleteGameConfirm():
 	return
 
 def DeleteGameCancel():
+	global ConfirmWindow
+
 	if ConfirmWindow:
 		ConfirmWindow.Unload()
+		ConfirmWindow = None
 	SaveWindow.SetVisible (WINDOW_VISIBLE)
 	return
 
@@ -299,11 +302,11 @@ def ConfirmedSaveGame ():
 	# We have to close floating window first
 	OpenSaveDetailWindow ()
 	LoadScreen.StartLoadScreen (LoadScreen.LS_TYPE_SAVING)
+	CloseSaveWindow ()
 	if Pos < len(Games):
 		GemRB.SaveGame (Games[Pos], Slotname)
 	else:
 		GemRB.SaveGame (None, Slotname)
-	CloseSaveWindow ()
 
 
 # Exit either back to game or to the Start window
