@@ -22,6 +22,6 @@
 #include "System/DataStream.h"
 
 GEM_EXPORT DataStream* CacheCompressedStream(DataStream *stream, const char* filename, int length = 0, bool overwrite = false);
-GEM_EXPORT DataStream* CacheFile(const char* path);
+GEM_EXPORT DataStream* CacheStream(DataStream* src);
 
 #endif
