@@ -62,11 +62,14 @@ class GEM_EXPORT ScrollBar : public Control {
 public:
 	ScrollBar(void);
 	~ScrollBar(void);
+	/** safe method to get the height of a frame */
+	int GetFrameHeight(int frame) const;
 	/**sets position, updates associated stuff */
-	void SetPos(ieDword NewPos);
+	void SetPos(ieDword NewPos, bool redraw = true);
 	void SetPosForY(unsigned short y);
 	void ScrollUp();
 	void ScrollDown();
+	double GetStep();
 	/**redraws scrollbar if associated with VarName */
 	void RedrawScrollBar(const char* VarName, int Sum);
 	/**/
@@ -77,6 +80,8 @@ private: //Private attributes
 	unsigned short SliderYPos;
 	/** Item Index */
 	unsigned short Pos;
+	/** slider y delta between steps */
+	double stepPx;
 	/** Scroll Bar Status */
 	unsigned short State;
 public:
