@@ -333,12 +333,12 @@ void Highlightable::TryDisarm(Actor *actor)
 		AddTrigger(TriggerEntry(trigger_disarmed, actor->GetGlobalID()));
 		//trap removed
 		Trapped = 0;
-		displaymsg->DisplayConstantStringName(STR_DISARM_DONE, 0xd7d7be, actor);
+		displaymsg->DisplayConstantStringName(STR_DISARM_DONE, DMC_LIGHTGREY, actor);
 		int xp = actor->CalculateExperience(XP_DISARM, actor->GetXPLevel(1));
 		Game *game = core->GetGame();
 		game->ShareXP(xp, SX_DIVIDE);
 	} else {
-		displaymsg->DisplayConstantStringName(STR_DISARM_FAIL, 0xd7d7be, actor);
+		displaymsg->DisplayConstantStringName(STR_DISARM_FAIL, DMC_LIGHTGREY, actor);
 		TriggerTrap(skill, actor->GetGlobalID());
 	}
 	ImmediateEvent();
@@ -349,19 +349,19 @@ void Door::TryPickLock(Actor *actor)
 	core->PlaySound(DS_PICKLOCK);
 	if (LockDifficulty == 100) {
 		if (OpenStrRef != (ieDword)-1) {
-			displaymsg->DisplayStringName(OpenStrRef, 0xbcefbc, actor, IE_STR_SOUND|IE_STR_SPEECH);
+			displaymsg->DisplayStringName(OpenStrRef, DMC_BG2XPGREEN, actor, IE_STR_SOUND|IE_STR_SPEECH);
 		} else {
-			displaymsg->DisplayConstantStringName(STR_DOOR_NOPICK, 0xbcefbc, actor);
+			displaymsg->DisplayConstantStringName(STR_DOOR_NOPICK, DMC_BG2XPGREEN, actor);
 		}
 		return;
 	}
 	if (actor->GetStat(IE_LOCKPICKING)<LockDifficulty) {
-		displaymsg->DisplayConstantStringName(STR_LOCKPICK_FAILED, 0xbcefbc, actor);
+		displaymsg->DisplayConstantStringName(STR_LOCKPICK_FAILED, DMC_BG2XPGREEN, actor);
 		AddTrigger(TriggerEntry(trigger_picklockfailed, actor->GetGlobalID()));
 		return;
 	}
 	SetDoorLocked( false, true);
-	displaymsg->DisplayConstantStringName(STR_LOCKPICK_DONE, 0xd7d7be, actor);
+	displaymsg->DisplayConstantStringName(STR_LOCKPICK_DONE, DMC_LIGHTGREY, actor);
 	AddTrigger(TriggerEntry(trigger_unlocked, actor->GetGlobalID()));
 	ImmediateEvent();
 	int xp = actor->CalculateExperience(XP_LOCKPICK, actor->GetXPLevel(1));
@@ -378,11 +378,11 @@ void Door::TryBashLock(Actor *actor)
 	unsigned int roll = actor->LuckyRoll(1, 10, bonus, 0);
 
 	if(roll < LockDifficulty || LockDifficulty == 100) {
-		displaymsg->DisplayConstantStringName(STR_DOORBASH_FAIL, 0xbcefbc, actor);
+		displaymsg->DisplayConstantStringName(STR_DOORBASH_FAIL, DMC_BG2XPGREEN, actor);
 		return;
 	}
 
-	displaymsg->DisplayConstantStringName(STR_DOORBASH_DONE, 0xd7d7be, actor);
+	displaymsg->DisplayConstantStringName(STR_DOORBASH_DONE, DMC_LIGHTGREY, actor);
 	SetDoorLocked(false, true);
 	//Is this really useful ?
 	AddTrigger(TriggerEntry(trigger_unlocked, actor->GetGlobalID()));
